@@ -25,25 +25,30 @@ class GiftCardsApi(BaseApi):
         a subset of the gift cards.
 
         Args:
-            mtype (string, optional): If a type is provided, gift cards of
-                this type are returned  (see [GiftCardType]($m/GiftCardType)).
-                If no type is provided, it returns gift cards of all types.
-            state (string, optional): If the state is provided, it returns the
-                gift cards in the specified state  (see
-                [GiftCardStatus]($m/GiftCardStatus)). Otherwise, it returns
-                the gift cards of all states.
-            limit (int, optional): If a value is provided, it returns only
-                that number of results per page. The maximum number of results
-                allowed per page is 50. The default value is 30.
+            mtype (string, optional): If a [type]($m/GiftCardType) is
+                provided, the endpoint returns gift cards of the specified
+                type. Otherwise, the endpoint returns gift cards of all
+                types.
+            state (string, optional): If a [state]($m/GiftCardStatus) is
+                provided, the endpoint returns the gift cards in the specified
+                state. Otherwise, the endpoint returns the gift cards of all
+                states.
+            limit (int, optional): If a limit is provided, the endpoint
+                returns only the specified number of results per page. The
+                maximum value is 50. The default value is 30. For more
+                information, see
+                [Pagination](https://developer.squareup.com/docs/working-with-a
+                pis/pagination).
             cursor (string, optional): A pagination cursor returned by a
                 previous call to this endpoint. Provide this cursor to
                 retrieve the next set of results for the original query. If a
-                cursor is not provided, it returns the first page of the
-                results.  For more information, see
+                cursor is not provided, the endpoint returns the first page of
+                the results.  For more information, see
                 [Pagination](https://developer.squareup.com/docs/working-with-a
                 pis/pagination).
-            customer_id (string, optional): If a value is provided, returns
-                only the gift cards linked to the specified customer
+            customer_id (string, optional): If a customer ID is provided, the
+                endpoint returns only the gift cards linked to the specified
+                customer.
 
         Returns:
             ApiResponse: An object with the response value as well as other
@@ -129,7 +134,7 @@ class GiftCardsApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
@@ -177,7 +182,7 @@ class GiftCardsApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
@@ -197,8 +202,8 @@ class GiftCardsApi(BaseApi):
                                       body):
         """Does a POST request to /v2/gift-cards/from-nonce.
 
-        Retrieves a gift card using a nonce (a secure token) that represents
-        the gift card.
+        Retrieves a gift card using a secure payment token that represents the
+        gift card.
 
         Args:
             body (RetrieveGiftCardFromNonceRequest): An object containing the
@@ -226,7 +231,7 @@ class GiftCardsApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
@@ -247,10 +252,11 @@ class GiftCardsApi(BaseApi):
                                    body):
         """Does a POST request to /v2/gift-cards/{gift_card_id}/link-customer.
 
-        Links a customer to a gift card
+        Links a customer to a gift card, which is also referred to as adding a
+        card on file.
 
         Args:
-            gift_card_id (string): The ID of the gift card to link.
+            gift_card_id (string): The ID of the gift card to be linked.
             body (LinkCustomerToGiftCardRequest): An object containing the
                 fields to POST for the request.  See the corresponding object
                 definition for field details.
@@ -279,7 +285,7 @@ class GiftCardsApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
@@ -300,10 +306,11 @@ class GiftCardsApi(BaseApi):
                                        body):
         """Does a POST request to /v2/gift-cards/{gift_card_id}/unlink-customer.
 
-        Unlinks a customer from a gift card
+        Unlinks a customer from a gift card, which is also referred to as
+        removing a card on file.
 
         Args:
-            gift_card_id (string): TODO: type description here.
+            gift_card_id (string): The ID of the gift card to be unlinked.
             body (UnlinkCustomerFromGiftCardRequest): An object containing the
                 fields to POST for the request.  See the corresponding object
                 definition for field details.
@@ -332,7 +339,7 @@ class GiftCardsApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
